@@ -1,9 +1,9 @@
 import sys
-from PyQt5.QtCore import Qt
 from pathlib import Path
 
 import pkg_resources
 from PyQt5 import QtWidgets
+from PyQt5.QtCore import Qt
 from PyQt5.QtGui import QIcon, QPixmap
 
 import activate.app.dialogs
@@ -13,12 +13,13 @@ from activate import (
     activity,
     activity_list,
     files,
+    filetypes,
     load_activity,
     serialise,
     track,
     units,
 )
-from activate.app import activity_view, connect, maps, paths, settings
+from activate.app import activity_view, connect, maps, paths, settings, widgets
 from activate.app.ui.main import Ui_main_window
 
 SYNC_PROGRESS_STEPS = 1000
@@ -37,7 +38,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
         # Create a global map widget to be used everywhere. This is
         # necessary because pyqtlet doesn't support multiple L.map
         # instances.
-        self.map_widget = maps.MapWidget(self)
+        self.map_widget = maps.MapWidget(self, self.settings.tiles)
 
         self.activity_summary.setup(self.unit_system, self.map_widget)
         self.social_activity_summary.setup(self.unit_system, self.map_widget)
@@ -56,6 +57,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
             (self.action_edit, "document-edit"),
             (self.action_analyse, "view-statistics"),
             (self.action_add_photos, "insert-image"),
+            (self.action_general, "settings-configure"),
             (self.action_units, "measure"),
             (self.action_servers, "network-server"),
             (self.export_menu, "document-send"),
@@ -65,20 +67,25 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
 
         self.main_tab_switch(0)
 
-    def edit_unit_settings(self):
+    def edit_settings(self, tab):
         settings_window = activate.app.dialogs.settings.SettingsDialog()
-        self.settings = settings_window.exec(self.settings, "Units")
+        self.settings = settings_window.exec(self.settings, tab)
+
+    def edit_general_settings(self):
+        self.edit_settings("General")
+
+    def edit_unit_settings(self):
+        self.edit_settings("Units")
 
     def edit_server_settings(self):
-        settings_window = activate.app.dialogs.settings.SettingsDialog()
-        self.settings = settings_window.exec(self.settings, "Servers")
+        self.edit_settings("Servers")
 
         self.main_tabs.setTabVisible(2, bool(self.settings.servers))
 
     def add_manual_activity(self):
         manual_window = activate.app.dialogs.activity.ManualActivityDialog()
         data = manual_window.exec({})
-        if data:
+        if isinstance(data, dict):
             self.add_activity(
                 activity.Activity(
                     data["Name"],
@@ -197,6 +204,16 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
             return
         self.activity.export_original(filename)
 
+    def export_as_route(self):
+        out_name = f"{self.activity.name}.gpx"
+        filename = QtWidgets.QFileDialog.getSaveFileName(
+            self, "Export as Route", str(paths.HOME / out_name), "GPX file (*.gpx)"
+        )[0]
+        if not filename:
+            return
+        with open(filename, "w") as f:
+            f.write(filetypes.gpx.to_route(self.activity))
+
     def edit_activity_data(self):
         """
         Open the Edit Activity dialog.
@@ -278,14 +295,14 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
         self.activity_view = activity_view.ActivityView()
         self.activity_view.setup(self.unit_system, self.map_widget)
         try:
-            activity = (
+            activity_ = (
                 self.activity
                 if self.main_tabs.tabText(self.main_tabs.currentIndex()) == "Activities"
                 else self.social_activity
             )
         except AttributeError:
             return
-        self.activity_view.show_activity(activity)
+        self.activity_view.show_activity(activity_)
         self.activity_view.closed.connect(self.activity_view_closed)
         self.activity_view.create()
         self.activity_view.showMaximized()
@@ -296,15 +313,25 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
             self.action_match.setText("Find Matching")
             self.activity_list_table.filter({a.activity_id for a in self.activities})
         else:
-            self.activity_list_table.filter(
-                self.activities.get_matching(
-                    self.activity,
-                    progress=lambda x: activate.app.dialogs.progress(
-                        self, x, "Finding matching activities"
-                    ),
+            spinbox = QtWidgets.QSpinBox()
+            spinbox.setMinimum(1)
+            spinbox.setMaximum(500)
+            spinbox.setSuffix(" m")
+            tolerance = activate.app.dialogs.FormDialog(
+                widgets.Form({"Tolerance": spinbox})
+            ).exec({"Tolerance": 40})
+            if tolerance:
+                tolerance = tolerance["Tolerance"]
+                self.activity_list_table.filter(
+                    self.activities.get_matching(
+                        self.activity,
+                        tolerance=tolerance,
+                        progress=lambda x: activate.app.dialogs.progress(
+                            self, x, "Finding matching activities"
+                        ),
+                    )
                 )
-            )
-            self.action_match.setText("Clear Match")
+                self.action_match.setText("Clear Match")
         self.activity_list_table.setUpdatesEnabled(True)
 
     def activity_view_closed(self):
@@ -350,6 +377,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
             self,
         )
         dialog.setWindowModality(Qt.WindowModal)
+        dialog.setMinimumDuration(2)
         dialog.forceShow()
         for i, server in enumerate(self.settings.servers):
             dialog.setLabelText(f"Getting activity list from {server.name}")
@@ -360,7 +388,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
                 )
             except connect.requests.RequestException:
                 continue
-            own_ids = set(a.activity_id for a in self.activities)
+            own_ids = {a.activity_id for a in self.activities}
             dialog.setValue(round(SYNC_PROGRESS_STEPS * (i + 1 / 3)))
             dialog.setLabelText(f"Syncing activities with {server.name}")
             for j, activity_ in enumerate(server_activities):
