@@ -16,42 +16,61 @@ DEFAULT_POS = [53, -1]
 ACTIVATE_COLOUR = "#802090"
 
 
-def call_js_method(obj, method, *params) -> None:
-    """Call obj.method(*params) equivalent in JavaScript."""
-    obj.runJavaScript(f"{obj.jsName}.{method}({','.join(str(x) for x in params)});")
+class Js:
+    def __init__(self, obj):
+        self.obj = obj
+
+    def __getattr__(self, name):
+        def method(*params):
+            self.obj.runJavaScript(
+                f"{self.obj.jsName}.{name}({','.join(str(x) for x in params)});"
+            )
+
+        return method
 
 
 class Polyline(L.polyline):
     def setLatLngs(self, coordinates):
-        call_js_method(self, "setLatLngs", coordinates)
+        Js(self).setLatLngs(coordinates)
 
 
 class CircleMarker(L.circleMarker):
     def setLatLng(self, coordinates):
-        call_js_method(self, "setLatLng", coordinates)
+        Js(self).setLatLng(coordinates)
 
 
 class Map(pyqtlet.MapWidget):
-    def __init__(self, parent):
+    def __init__(self, parent, tiles):
         super().__init__()
         size_policy = self.sizePolicy()
         size_policy.setRetainSizeWhenHidden(True)
         self.setSizePolicy(size_policy)
         self.setContextMenuPolicy(Qt.NoContextMenu)
         self.map = L.map(self)
-        L.tileLayer(
-            "http://{s}.tile.osm.org/{z}/{x}/{y}.png",
-            {"attribution": "&copy; OpenStreetMap contributors"},
-        ).addTo(self.map)
+        if tiles is None:
+            L.tileLayer(
+                "http://{s}.tile.osm.org/{z}/{x}/{y}.png",
+                {"attribution": "&copy; OpenStreetMap contributors"},
+            ).addTo(self.map)
+        else:
+            L.tileLayer(tiles, {"attribution": ""}).addTo(self.map)
 
         self.map.runJavaScript(f"{self.map.jsName}.attributionControl.setPrefix('');")
+        self.moved = False
+
+    def fit_bounds(self, bounds):
+        if self.moved:
+            Js(self.map).flyToBounds(bounds)
+        else:
+            Js(self.map).fitBounds(bounds)
+            self.moved = True
 
 
 class MapWidget(Map):
-    """A map for displaying a route or heatmap"""
+    """A map for displaying a route or heatmap."""
 
-    def __init__(self, parent):
-        super().__init__(parent)
+    def __init__(self, parent, tiles):
+        super().__init__(parent, tiles)
         self.route_lines = []
         self.start_icon = CircleMarker(DEFAULT_POS, {"radius": 8, "color": "#10b020"})
         self.finish_icon = CircleMarker(DEFAULT_POS, {"radius": 8, "color": "#e00000"})
@@ -61,7 +80,7 @@ class MapWidget(Map):
 
     def show_route(self, route: list):
         """Display a list of points on the map."""
-        self.map.fitBounds(get_bounds(route))
+        self.fit_bounds(get_bounds(route))
         if self.mode != "route":
             self.clear_route_lines()
             self.route_lines = [self.add_route_line()]
@@ -77,7 +96,7 @@ class MapWidget(Map):
         if not routes:
             return
         colour = ACTIVATE_COLOUR + hex(min(round(1000 / (len(routes) ** 0.5)), 255))[2:]
-        self.map.fitBounds(get_bounds(*routes))
+        self.fit_bounds(get_bounds(*routes))
         self.start_icon.removeFrom(self.map)
         self.finish_icon.removeFrom(self.map)
         self.clear_route_lines()
@@ -109,7 +128,7 @@ class MapWidget(Map):
     def show_highlight(self, part):
         self.highlight_section.setLatLngs(part)
         self.highlight_section.addTo(self.map)
-        call_js_method(self.highlight_section, "bringToFront")
+        Js(self.highlight_section).bringToFront
 
     def remove_highlight(self):
         self.highlight_section.removeFrom(self.map)
