@@ -1,19 +1,24 @@
 """Contains a class holding current user settings."""
 import dataclasses
+from contextlib import suppress
+from typing import Optional
 
 from activate import serialise, units
 from activate.app import connect, paths
 
-DEFAULTS = {"unit_system": units.DEFAULT, "servers": [], "custom_units": {}}
+DEFAULTS = {
+    "tiles": None,
+    "unit_system": units.DEFAULT,
+    "servers": [],
+    "custom_units": {},
+}
 
 
 def load_settings():
     """Load settings from a configuration file."""
     settings_data = DEFAULTS.copy()
-    try:
+    with suppress(FileNotFoundError):
         settings_data.update(serialise.load(paths.SETTINGS))
-    except FileNotFoundError:
-        pass
 
     settings_data["servers"] = [connect.Server(**s) for s in settings_data["servers"]]
     return Settings(**settings_data)
@@ -21,8 +26,9 @@ def load_settings():
 
 @dataclasses.dataclass
 class Settings:
-    """A settings configuration"""
+    """A settings configuration."""
 
+    tiles: Optional[str]
     unit_system: str
     custom_units: dict
     servers: list
