@@ -31,7 +31,10 @@ class Summary(QtWidgets.QWidget, Ui_summary):
         self.progression_chart.set_units(self.unit_system)
         self.update_activity_types_list()
         self.eddington_chart = charts.LineChart(
-            self.eddington_chart_widget, self.unit_system, series_count=2
+            self.eddington_chart_widget,
+            self.unit_system,
+            series_count=2,
+            vertical_log=True,
         )
         self.eddington_chart.y_axis.setTitleText("Count")
         self.eddington_chart.add_legend(("Done", "Target"))
@@ -115,10 +118,19 @@ class Summary(QtWidgets.QWidget, Ui_summary):
             good_distances,
             lambda x: progress(self, list(x), "Loading"),
         )
-
-        self.records_table.update_data(
-            list(good_distances.values()), records, activity_ids
-        )
+        try:
+            first_non_one_second = max(
+                next(
+                    i for i, r in enumerate(records) if r[1].value.total_seconds() > 1
+                ),
+                1,
+            )
+        except StopIteration:
+            first_non_one_second = 0
+        records = records[first_non_one_second - 1 :]
+        activity_ids = list(activity_ids)[first_non_one_second - 1 :]
+        good_distances = list(good_distances.values())[first_non_one_second - 1 :]
+        self.records_table.update_data(good_distances, records, activity_ids)
 
     def update_gallery(self):
         self.gallery.replace_photos(
@@ -147,7 +159,7 @@ class Summary(QtWidgets.QWidget, Ui_summary):
         if not allowed_activities:
             return
         unit = self.unit_system.units["distance"].size
-        eddington_data = self.activities.eddington(allowed_activities, unit)
+        eddington_data = self.activities.eddington(allowed_activities)
         eddington_number = 0
         for eddington_number in range(1, len(eddington_data) + 1):
             if eddington_data[eddington_number - 1] <= eddington_number * unit:
