@@ -21,7 +21,7 @@ FIELDS = {
 }
 
 
-def load_gpx(filename) -> tuple:
+def load(filename) -> tuple:
     """Extract the fields from a GPX file."""
     tree = load_xml.get_tree(filename)
     # Find the activity name
@@ -39,3 +39,19 @@ def load_gpx(filename) -> tuple:
 
     points = tree.findall("./trk/trkseg/trkpt")
     return (name, sport, load_xml.load_fields(points, FIELDS))
+
+
+def to_route(activity):
+    name, track = activity.name, activity.track
+    gpx = [
+        '<?xml version="1.0" encoding="UTF-8"?>'
+        '<gpx version="1.1" xmlns="http://www.topografix.com/GPX/1/1">'
+        f"<metadata><name>{name}</name></metadata><trk><trkseg>"
+    ]
+    for p in range(len(track)):
+        gpx.append(
+            f'<trkpt lat="{track["lat"][p]}" lon="{track["lon"][p]}">'
+            f'<ele>{track["ele"][p]}</ele></trkpt>"'
+        )
+    gpx.append("</trkseg></trk></gpx>")
+    return "".join(gpx)
