@@ -41,7 +41,7 @@ def lerp(value1, value2, ratio):
     lerp(x, y, 0.5) = (x + y) / 2
     lerp(x, y, 1) = y
     """
-    return value1 * (1 - ratio) + value2 * ratio
+    return value1 + ratio * (value2 - value1)
 
 
 def infer_nones(data):
@@ -88,7 +88,7 @@ def get_nearby_indices(length, position, number=1) -> range:
 
 
 try:
-    import dist
+    from math import dist
 except ImportError:
 
     def dist(point1, point2):
@@ -117,7 +117,7 @@ class ManualTrack:
             return self.length / self.elapsed_time.total_seconds()
         raise AttributeError(f"{self.__class__.__qualname__} has no average {field}")
 
-    def __contains__(*_):
+    def __contains__(self, _):
         return False
 
 
@@ -197,7 +197,7 @@ class Track:
         ]
 
     def calculate_dist_to_last(self):
-        """Calculate distances between adjacent points"""
+        """Calculate distances between adjacent points."""
         self.fields["dist_to_last"] = [None]
         if "dist" in self.fields:
             for point in range(1, len(self)):
@@ -221,7 +221,7 @@ class Track:
             self.fields["desc"].append(0 if height_change >= 0 else -height_change)
 
     def calculate_dist(self):
-        """Calculate cumulative distances"""
+        """Calculate cumulative distances."""
         total_dist = 0
         new_dist = [0]
         for dist in self["dist_to_last"][1:]:
@@ -230,7 +230,7 @@ class Track:
         self.fields["dist"] = new_dist
 
     def calculate_speed(self):
-        """Calculate speeds at each point"""
+        """Calculate speeds at each point."""
         speeds = []
         for point_index in range(len(self)):
             relevant_points = get_nearby_indices(
@@ -461,15 +461,15 @@ class Track:
         lasttime = None
         lastalt = None
         total_climb = 0
-        for time, dist, alt, climb in zip(
+        for time, distance, alt, climb in zip(
             self["time"], self["dist"], self["ele"], self["climb"]
         ):
             if lasttime is None:
                 lasttime = time
                 lastalt = alt
-            if dist is None:
+            if distance is None:
                 continue
-            if dist // splitlength > len(splits):
+            if distance // splitlength > len(splits):
                 speed = splitlength / (time - lasttime).total_seconds()
                 splits.append(
                     [
@@ -525,9 +525,9 @@ class Track:
         bests = []
         point_indices = []
         for distance in table_distances:
-            for last_point, last_dist in enumerate(self["dist"]):
-                if last_dist is not None and last_dist > distance:
-                    break
+            last_point = next(
+                i for i, d in enumerate(self["dist"]) if d is not None and d > distance
+            )
             best = time_values[last_point] - self.start_time.timestamp()
             first_point = 0
             point = (first_point, last_point)
@@ -570,8 +570,19 @@ class Track:
             point_indices,
         )
 
-    def match(self, other):
-        return dtw(self.xyz, other.xyz, distance_only=True).normalizedDistance < 40
+    def match(self, other, tolerance=40):
+        return (
+            dtw(self.xyz, other.xyz, distance_only=True).normalizedDistance < tolerance
+        )
+
+    def max_point(self, stat):
+        point = None
+        maximum = float("-inf")
+        for index, value in enumerate(self[stat]):
+            if value is not None and value > maximum:
+                maximum = value
+                point = index
+        return point
 
     @property
     def save_data(self):
